MacOsSigner

Struct MacOsSigner 

pub struct MacOsSigner { /* private fields */ }
Configuration for identity-based macOS signing.

Implementations

Source

impl MacOsSigner

pub fn from_env() -> Result<Option<Self>, CodesignConfigError>

Construct from environment variables.

Errors

Returns [Ok(None)] when none of the identity variables are set.

pub fn begin_session(&self) -> Result<MacOsSigningSession, CodesignError>

Create a signing session with a shared ephemeral keychain.

The session creates one ephemeral keychain, imports the certificate into it, and holds an exclusive file lock to prevent concurrent processes from racing on the macOS keychain search list. Use MacOsSigningSession::sign to sign individual files.

Errors